<!-- Improved compatibility of back to top link: See: https://github.com/othneildrew/Best-README-Template/pull/73 -->
<a name="readme-top"></a>
<!--
*** Thanks for checking out the Best-README-Template. If you have a suggestion
*** that would make this better, please fork the repo and create a pull request
*** or simply open an issue with the tag "enhancement".
*** Don't forget to give the project a star!
*** Thanks again! Now go create something AMAZING! :D
-->

<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/Scenerainc/SceneraNodeSDK">
    <img src="https://scenera.net/wp-content/uploads/elementor/thumbs/SCENERA_LOGO_DARK-nbpbqja5s29uzukp9s95ak9ebwhmant9wqq1a79b7k-prsgz2hfl6umza6rcekzcpcmep255cxhkjq1573z7k.png" alt="Logo" width="180" height="80">
  </a>

<h3 align="center">Scenera Node SDK (docs under construction)</h3>

  <p align="center">
    Enables algorithms to be linked to the Scenera PaaS.
    <br />
    <a href="https://docs.scenera.live/"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/Scenerainc/ExampleNode">View Demo</a>
    ·
    <a href="https://github.com/Scenerainc/SceneraNodeSDK/issues">Report Bug</a>
    ·
    <a href="https://github.com/Scenerainc/SceneraNodeSDK/issues">Request Feature</a>
  </p>
</div>


<!-- ABOUT THE PROJECT -->
## About The Project

[![Product Name Screen Shot][product-screenshot]](https://example.com)

Here's a blank template to get started: To avoid retyping too much info. Do a search and replace with your text editor for the following: `github_username`, `repo_name`, `twitter_handle`, `linkedin_username`, `email_client`, `email`, `project_title`, `project_description`

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- GETTING STARTED -->
## Getting Started

This is an example of how you may give instructions on setting up your project locally.
To get a local copy up and running follow these simple example steps.

### Installation

`pip install scenera.node`

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- USAGE EXAMPLES -->
## Usage

There is an Example Node that can be found [here](https://github.com/Scenerainc/ExampleNode)

_For more examples, please refer to the [Documentation](https://example.com)_

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- LICENSE -->
## License

Distributed under the MIT License. See [LICENSE](./LICENSE) for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- CONTACT -->
## Contact

Dirk Meulenbelt - dirk.meulenbelt@scenera.net

<p align="right">(<a href="#readme-top">back to top</a>)</p>